Stan Math Library: stan/math/prim/mat/meta/get.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

get.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_META_GET_HPP
2 #define STAN_MATH_PRIM_MAT_META_GET_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5
6 namespace stan {
7
8 template <typename T, int R, int C>
9 inline T get(const Eigen::Matrix<T, R, C>& m, size_t n) {
10 return m(static_cast<int>(n));
11 }
12
13 }
14 #endif
15
stan
Definition: log_sum_exp.hpp:8
Eigen.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.